# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

_Public Classes_

* [`proftpd`](#proftpd): Install and configure ProFTPD

_Private Classes_

* `proftpd::config`: Setup ProFTPD configuration
* `proftpd::install`: Install ProFTPD packages
* `proftpd::service`: Manage the ProFTPD service

**Defined types**

_Public Defined types_

* [`proftpd::ftpasswd_user`](#proftpdftpasswd_user): Add a user to ftpasswd

_Private Defined types_

* `proftpd::module`: Load a ProFTPD module

## Classes

### proftpd

Install and configure ProFTPD

#### Parameters

The following parameters are available in the `proftpd` class.

##### `config_template`

Data type: `String[1]`

Specify which erb template to use.

##### `default_config`

Data type: `Boolean`

Set to `false` to disable loading of the default configuration. Defaults to `true`.

##### `manage_config_file`

Data type: `Boolean`

Set to `false` to disable managing of the ProFTPD configuration file(s).

##### `manage_ftpasswd_file`

Data type: `Boolean`

Set to `false` to disable managing of the ProFTPD ftpasswd file.

##### `package_ensure`

Data type: `String`

Overwrite the package `ensure` parameter.

##### `package_manage`

Data type: `Boolean`

Set to `false` to disable package management. Defaults to `true`.

##### `service_manage`

Data type: `Boolean`

Set to `false` to disable service management. Defaults to `true`.

##### `service_enable`

Data type: `Boolean`

Set to `false` to disable the ProFTPD system service. Defaults to `true`.

##### `service_ensure`

Data type: `String`

Overwrite the service `ensure` parameter.

##### `prefix`

Data type: `Optional[Stdlib::Absolutepath]`

Prefix to be added to all paths. Only required on certain operating systems
or special installations.

Default value: `undef`

##### `config_mode`

Data type: `Stdlib::Filemode`

File mode to be used for config files. Defaults to `0644`.

##### `prefix_bin`

Data type: `Stdlib::Absolutepath`

Path to the ProFTPD binary.

##### `config`

Data type: `Stdlib::Absolutepath`

Path to the ProFTPD configuration file.

##### `base_dir`

Data type: `Stdlib::Absolutepath`

Directory for additional configuration files.

##### `log_dir`

Data type: `Stdlib::Absolutepath`

Directory for log files.

##### `run_dir`

Data type: `Stdlib::Absolutepath`

Directory for runtime files (except PIDfile).

##### `packages`

Data type: `Array[String[1]]`

An array of packages which should be installed.

##### `service_name`

Data type: `String[1]`

The name of the ProFTPD service.

##### `user`

Data type: `String[1]`

Set the user under which the server will run.

##### `group`

Data type: `String[1]`

Set the group under which the server will run.

##### `config_user`

Data type: `String[1]`

Set the user that should own all configuration files.

##### `config_group`

Data type: `String[1]`

Set the user that should own all configuration files.

##### `pidfile`

Data type: `Stdlib::Absolutepath`

Path and name of the PID file for the ProFTPD service.

##### `scoreboardfile`

Data type: `Stdlib::Absolutepath`

Path and name of the ScoreboardFile for the ProFTPD service.

##### `ftpasswd_file`

Data type: `Stdlib::Absolutepath`

Path and name of the ftpasswd file.

##### `anonymous_options`

Data type: `Hash`

An optional hash containing the default options to configure ProFTPD for
anonymous FTP access. Use this to overwrite these defaults.

##### `anonymous_enable`

Data type: `Boolean`

Set to `true` to enable loading of the `$anonymous_options` hash.

##### `default_options`

Data type: `Hash`

A hash containing a set of working default options for ProFTPD. This should
make it easy to get a running service and to overwrite a few settings.

##### `load_modules`

Data type: `Hash`

A hash of optional ProFTPD modules to load. It is possible to load modules
in a specific order by using the order attribute.

##### `options`

Data type: `Hash`

Specify a hash containing options to either overwrite the default options or
configure ProFTPD from scratch. Will be merged with `$default_options` hash
(as long as `$default_config` is not set to `false`).

##### `authuserfile_source`

Data type: `Optional[Stdlib::Filesource]`

Inject the AuthUserFile by defining a Puppet source (e.g. puppet:///modules/mymodule/ftpd.passwd)

Default value: `undef`

##### `authgroupfile_source`

Data type: `Optional[Stdlib::Filesource]`

Inject the AuthGroupFile by defining a Puppet source (e.g. puppet:///modules/mymodule/ftpd.group)

Default value: `undef`

## Defined types

### proftpd::ftpasswd_user

Add a user to ftpasswd

#### Parameters

The following parameters are available in the `proftpd::ftpasswd_user` defined type.

##### `hashed_passwd`

Data type: `Any`

A hashed password.

##### `uid`

Data type: `Any`

The UID of the user.

##### `gid`

Data type: `Any`

The GID of the user.

##### `homedir`

Data type: `Any`

The home directory of the user.

Default value: "/home/${name}"

##### `shell`

Data type: `Any`

The shell of the user.

Default value: '/bin/false'

##### `username`

Data type: `Any`

(Namevar) The user's login name.

Default value: $name

##### `gecos`

Data type: `Any`

The GECOS field with additional (optional) information about the user.

Default value: $name

##### `ftpasswd_file`

Data type: `Any`

The target ftpasswd file.

Default value: $proftpd::ftpasswd_file

